<?php
/*
Plugin Name: Recent Links
Version: 2.01
Plugin URI: http://rebelpixel.com/projects/wp-recent-links/
Description: A linklog plugin for WordPress, allowing you to have your own blog of links without the need for another wp-powered weblog or (gasp!) another weblog software. More information at the <a href="http://rebelpixel.com/projects/wp-recent-links/">project's page</a>.
Author: Markku Seguerra
Author URI: http://rebelpixel.com/
*/

$rp_new_title = '';

/* =========================================================================
                                                    ++++++++++++++++++++++++
                                                    ++  rp_recentlinks()  ++
                                                    ++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the most recent links added to your linklog.

$limit
    The number of links to display.
    Defaults to 12.

$use_permalink
    Use permalinks for your links? True or False.
    Defaults to false.

$permalink_beginning
    Permalink at the beginning of the link? True or False.
    Defaults to True.

$permalink_icon
    Permalink icon used.
    Defaults to the commonly-used '#' character.

$inline_caption
    Use inline captions, in addition to the title attribute.
    Defaults to false.

$date_append
    Date format of the date string added for a link's title attribute.
    This is based on PHP's date() function.
    Defaults to 'F j', which displays March 22.
    Other suggested formats:
        jS M Y @ g A    ==>     22nd Mar 2004 @ 5 PM
        M j             ==>     Mar 22

$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
// 2004-05-18 16:57:11
function rp_recentlinks($limit = 12,
                        $use_permalink = false,
                        $permalink_beginning = true,
                        $permalink_icon = '#',
                        $inline_caption = false,
                        $date_append = 'F j',
                        $before = '<li>',
                        $after = '</li>',
                        $between = "\n")
{
    global $table_prefix, $wpdb;

    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';
    $time_difference = get_settings('gmt_offset');

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }

    $now = gmdate('Y-m-d H:i:s',(time() + ($time_difference * 3600)));
    $sql = "SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' ORDER BY date_added DESC $limit";

    $links = $wpdb->get_results($sql);

    if ($links) {

        $out = '';
        foreach ($links as $link) {

            $link->link_text = stripslashes($link->link_text);
            $link->link_url = stripslashes($link->link_url);
            $link->link_caption = stripslashes($link->link_caption);
            $link->link_rel = stripslashes($link->link_rel);
            $link->link_target = stripslashes($link->link_target);

            $this_date = date($date_append, strtotime($link->date_added));

            if (strlen($link->link_caption) > 0) {
                $piped_caption = ' | '.$link->link_caption;
            } else {
                $piped_caption = '';
            }

            if (strlen($link->link_rel) == 0) {
                $rel = '';
            } else {
                $rel = ' rel="'.$link->link_rel.'"';
            }

            if (strlen($link->link_target) == 0) {
                $target = '';
            } else {
                $target = ' target="'.$link->link_target.'"';
            }


            if (  is_int(strpos($link->link_url, '&'))  &&  !strpos($link->link_url, '&amp;')  &&  !strpos($link->link_url, '&#038;')  ) {
                $link->link_url = str_replace('&', '&amp;', $link->link_url);
            }


            if (  is_int(strpos($link->link_text, $a_tag))  &&  is_int(strpos($link->link_text, $a_tag2))  ) {
                $pos_open = strpos($link->link_text, $a_tag);
                $pos_close = strpos($link->link_text, $a_tag2, $pos_open);

                $prefix = substr($link->link_text, 0, $pos_open);
                $suffix = substr($link->link_text, $pos_close + strlen($a_tag2));

                $middle = substr($link->link_text, $pos_open + strlen($a_tag), $pos_close - ($pos_open + strlen($a_tag)));

                $new_link = $prefix.'<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.'>'.wptexturize($middle).'</a>'.$suffix;
            } else {
                $new_link = '<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.'>'.wptexturize($link->link_text).'</a>';
            }


            if ($use_permalink) {
                $siteurl = get_settings('siteurl');
                $rewrite = get_settings('permalink_structure');
                if (strlen($permalink_icon) == 0) {
                    $permalink_icon = '#';
                }
                if (strlen($rewrite) > 0) { // using mod_rewrite
                    $permalink_url = $siteurl.'/recent-links/'.date('Y/m', strtotime($link->date_added)).'/#rlink-'.$link->ID;
                } else {
                    $permalink_url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($link->date_added)).'&amp;m='.date('m', strtotime($link->date_added)).'#rlink-'.$link->ID;
                }

                if ($permalink_beginning) {
                    $new_link = '<a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a> '.$new_link;
                } else {
                    $new_link = $new_link.' <a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a>';
                }
            }


            if ($inline_caption) {
                $new_link = $new_link.'<br />'.wptexturize($link->link_caption);
            }


            $out .= $before.$new_link.$after.$between;

        }
    }
    echo $out;
}












/* =========================================================================
                                       +++++++++++++++++++++++++++++++++++++
                                       ++  rp_recentlinks_archives_url()  ++
                                       +++++++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the URL of the archives page for the
recent links plugin.

========================================================================= */
function rp_recentlinks_archives_url()
{
    $siteurl = get_settings('siteurl');
    $rewrite = get_settings('permalink_structure');

    if (strlen($rewrite) > 0) { // using mod_rewrite
        echo $siteurl.'/recent-links/';
    } else {
        echo $siteurl.'/wp-recent-links.php';
    }
}















/* =========================================================================
                                           +++++++++++++++++++++++++++++++++
                                           ++  rp_recentlinks_rss2_url()  ++
                                           +++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the URL of the RSS 2 feed for the
recent links plugin.

========================================================================= */
// 2004-05-18 17:07:04
function rp_recentlinks_rss2_url()
{
    $siteurl = get_settings('siteurl');
    $rewrite = get_settings('permalink_structure');

    if (strlen($rewrite) > 0) { // using mod_rewrite
        echo $siteurl.'/recent-links/feed/';
    } else {
        echo $siteurl.'/wp-recent-links-rss2.php';
    }
}









/* =========================================================================
                                              ++++++++++++++++++++++++++++++
                                              ++  rp_recentlinks_month()  ++
                                              ++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the links for the given month.

$limit
    The number of links to display.
    Defaults to 12.

$show_link_count
    Show link count for given month? True or False.
    Defaults to false.

$use_permalink
    Use permalinks for your links? True or False.
    Defaults to false.

$permalink_beginning
    Permalink at the beginning of the link? True or Flase.
    Defaults to True.

$permalink_icon
    Permalink icon used.
    Defaults to the commonly-used '#' character.

$inline_caption
    Use inline captions, in addition to the title attribute.
    Defaults to false.

$date_append
    Date format of the date string added for a link's title attribute.
    This is based on PHP's date() function.
    Defaults to 'F j', which displays March 22.
    Other suggested formats:
        jS M Y @ g A    ==>     22nd Mar 2004 @ 5 PM
        M j             ==>     Mar 22
$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
// 2004-05-18 17:06:57
function rp_recentlinks_month($limit = '',
                                $show_link_count = false,
                                $use_permalink = false,
                                $permalink_beginning = true,
                                $permalink_icon = '#',
                                $inline_caption = false,
                                $date_append = 'F j',
                                $before = '<li>',
                                $after = '</li>',
                                $between = "\n")
{
    global $table_prefix, $wpdb;
    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';
    $time_difference = get_settings('gmt_offset');

    $y = strip_tags($_REQUEST['y']);
    $m = strip_tags($_REQUEST['m']);

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }


    $now = gmdate('Y-m-d H:i:s',(time() + ($time_difference * 3600)));

    $links = $wpdb->get_results("SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' AND YEAR(date_added) = '$y' AND MONTH(date_added) = '$m' ORDER BY date_added DESC" . $limit);

    if ($links) {

        $out = '';
        foreach ($links as $link) {

            $link->link_text = stripslashes($link->link_text);
            $link->link_url = stripslashes($link->link_url);
            $link->link_caption = stripslashes($link->link_caption);
            $link->link_rel = stripslashes($link->link_rel);
            $link->link_target = stripslashes($link->link_target);

            $this_date = date($date_append, strtotime($link->date_added));

            if (strlen($link->link_caption) > 0) {
                $piped_caption = ' | '.$link->link_caption;
            } else {
                $piped_caption = '';
            }

            if (strlen($link->link_rel) == 0) {
                $rel = '';
            } else {
                $rel = ' rel="'.$link->link_rel.'"';
            }
            if (strlen($link->link_target) == 0) {
                $target = '';
            } else {
                $target = ' target="'.$link->link_target.'"';
            }

            // ID for permalinks
            $id = ' id="rlink-'.$link->ID.'"';


            if (  is_int(strpos($link->link_url, '&'))  &&  !strpos($link->link_url, '&amp;')  &&  !strpos($link->link_url, '&#038;')  ) {
                $link->link_url = str_replace('&', '&amp;', $link->link_url);
            }


            if (  is_int(strpos($link->link_text, $a_tag))  &&  is_int(strpos($link->link_text, $a_tag2))  ) {
                $pos_open = strpos($link->link_text, $a_tag);
                $pos_close = strpos($link->link_text, $a_tag2, $pos_open);

                $prefix = substr($link->link_text, 0, $pos_open);
                $suffix = substr($link->link_text, $pos_close + strlen($a_tag2));

                $middle = substr($link->link_text, $pos_open + strlen($a_tag), $pos_close - ($pos_open + strlen($a_tag)));

                $new_link = $prefix.'<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.$id.'>'.wptexturize($middle).'</a>'.$suffix;
            } else {
                $new_link = '<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.$id.'>'.wptexturize($link->link_text).'</a>';
            }


            if ($use_permalink) {
                $siteurl = get_settings('siteurl');
                $rewrite = get_settings('permalink_structure');
                if (strlen($permalink_icon) == 0) {
                    $permalink_icon = '#';
                }
                if (strlen($rewrite) > 0) { // using mod_rewrite
                    $permalink_url = $siteurl.'/recent-links/'.date('Y/m', strtotime($link->date_added)).'/#rlink-'.$link->ID;
                } else {
                    $permalink_url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($link->date_added)).'&amp;m='.date('m', strtotime($link->date_added)).'#rlink-'.$link->ID;
                }


                if ($permalink_beginning) {
                    $new_link = '<a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a> '.$new_link;
                } else {
                    $new_link = $new_link.' <a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a>';
                }
            }

            if ($inline_caption) {
                $new_link = $new_link.'<br />'.wptexturize($link->link_caption);
            }


            $out .= $before.$new_link.$after.$between;

        }
    }
    echo $out;
}















/* =========================================================================
                                           +++++++++++++++++++++++++++++++++
                                           ++  rp_recentlinks_archives()  ++
                                           +++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the monthly archives for the recent links plugin.

$limit
    The number of links to display.
    Defaults to '', which shows all.

$show_link_count
    Show link count for given month? True or False.
    Defaults to false.

$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
function rp_recentlinks_archives($limit = '',
                                    $show_link_count = false,
                                    $before = '<li>',
                                    $after = '</li>',
                                    $between = "\n")
{
    global $table_prefix, $wpdb;
    $siteurl = get_settings('siteurl');
    $tablerecentlinks = $table_prefix.'recentlinks';
    $time_difference = get_settings('gmt_offset');

    $rewrite = get_settings('permalink_structure');

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }


    $now = gmdate('Y-m-d H:i:s',(time() + ($time_difference * 3600)));

    $arcresults = $wpdb->get_results("SELECT DISTINCT YEAR(date_added) AS `year`, MONTH(date_added) AS `month`, count(ID) as links, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' GROUP BY YEAR(date_added), MONTH(date_added) ORDER BY date_added DESC" . $limit);

    if ($arcresults) {
        $out = '';
        foreach ($arcresults as $month) {
            if (strlen($rewrite) > 0) {
                $url = $siteurl.'/recent-links/'.date('Y/m/', strtotime($month->date_added));
            } else {
                $url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($month->date_added)).'&amp;m='.date('m', strtotime($month->date_added));
            }

            if ($show_link_count) {
                $link_count = ' ('.$month->links.')';
            } else {
                $link_count = '';
            }

            $link = '<a href="'.$url.'" title="'.date('F Y', strtotime($month->date_added)).'">'.date('F Y', strtotime($month->date_added)).'</a>'. $link_count;

            $out .= $before.$link.$after.$between;
        }

    }
    echo $out;
}








/* =========================================================================
                                               +++++++++++++++++++++++++++++
                                               ++  rp_recentlinks_home()  ++
                                               +++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays links for the home page.

$default_days
    The number of days of links to display.
    Defaults to 7.

========================================================================= */
function rp_recentlinks_home($default_days = 7)
{
    return rp_recentlinks_archive_page(7);
}





/* =========================================================================
                                       +++++++++++++++++++++++++++++++++++++
                                       ++  rp_recentlinks_archive_page()  ++
                                       +++++++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays links for the archive page (or current month).

$default_days
    The number of days of links to display.
    Defaults to 30.

========================================================================= */
function rp_recentlinks_archive_page($default_days = 30)
{
    global $table_prefix, $wpdb;

    $y = '';
    $m = '';
    $d = '';

    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';


// begin## changes by Arthur Hoogervorst, thanks man.
//    if (strlen(get_settings('permalink_structure')) > 0) {
//        $y = strval($_GET['y']);
//        $m = strval($_GET['m']);
//    } else {
//        $y = strval(substr($_GET['m'], 0, 4));
//        if (strlen($_GET['m']) > 4) {
//            $m = strval(substr($_GET['m'], 4, 2));
//        }
//    }
    $y = strval($_GET['y']);
    $m = strval($_GET['m']);
// end##

    if (  strlen($y) == 4 && strlen($m) != 2 ) { //year
        $now       = $y.'-12-31 23:59:59';
        $last_day  = $y.'-01-01 00:00:00';
    } elseif (  strlen($y) == 4 && strlen($m) == 2 ) { //month
        if ( checkdate($m, '31', $y) ) {
            $now        = $y.'-'.$m.'-31 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '30', $y) ) {
            $now        = $y.'-'.$m.'-30 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '29', $y) ) {
            $now        = $y.'-'.$m.'-29 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } else {
            $now        = $y.'-'.$m.'-28 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        }
    } else {
        $now = gmdate('Y-m-d H:i:s',(time() + (get_settings('gmt_offset') * 3600)));
        $last_day = gmdate('Y-m-d H:i:s',((time()-(3600*24*$default_days)) + (get_settings('gmt_offset') * 3600))); // last 30 days of links
    }


    $sql = "SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND date_added > '$last_day' AND link_visible = 'Y' ORDER BY date_added DESC";

    $links = $wpdb->get_results($sql);

    if ($links) {

        for ($i=0; $i < count($links); $i++) {
            $links[$i]->link_text = stripslashes($links[$i]->link_text);
            $links[$i]->link_url = stripslashes($links[$i]->link_url);
            $links[$i]->link_caption = stripslashes($links[$i]->link_caption);
            $links[$i]->link_rel = stripslashes($links[$i]->link_rel);
            $links[$i]->link_target = stripslashes($links[$i]->link_target);

            if (strlen(get_settings('permalink_structure')) > 0) { // using mod_rewrite
                $links[$i]->link_permalink = get_settings('siteurl').'/recent-links/'.date('Y/m', strtotime($links[$i]->date_added)).'/#rlink-'.$links[$i]->ID;
            } else {
                $links[$i]->link_permalink = get_settings('siteurl').'/wp-recent-links.php?y='.date('Y', strtotime($links[$i]->date_added)).'&m='.date('m', strtotime($links[$i]->date_added)).'#rlink-'.$links[$i]->ID;
            }

            if (  is_int(strpos($links[$i]->link_url, '&'))  &&  !strpos($links[$i]->link_url, '&')  &&  !strpos($links[$i]->link_url, '&')  ) {
                $links[$i]->link_url = str_replace('&', '&', $links[$i]->link_url);
            }

            $links[$i]->link_text = strip_tags($links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag, '', $links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag2, '', $links[$i]->link_text);

        }
    }

    return $links;
}






/* =========================================================================
                                     +++++++++++++++++++++++++++++++++++++++
                                     ++  rp_recentlinks_archive_header()  ++
                                     +++++++++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays header for the archive page.

$links_name
    The name of the links section/header.
    Defaults to 'Recent Links'.

$date_format
    The date format of the links section/header, if date info is given.
    Based on PHP's date() function.
    Defaults to 'F Y' which is similar to 'March 2005'.

$separator
    The separator for the section name and date.
    Defaults to ' &#8250; ' which is similar to ' > '.

========================================================================= */
function rp_recentlinks_archive_header($links_name = 'Recent Links', $date_format = 'F Y', $separator = ' &raquo; ')
{
    global $rp_new_title;

    if (  isset($_GET['y']) && isset($_GET['m'])  ) {
        $rp_new_title = 'Recent Links'.$separator.date('F Y', strtotime($_GET['y'].'-'.$_GET['m'].'-01 01:01:01'));
    } else {
        $rp_new_title = 'Recent Links';
    }
    echo $rp_new_title;
}




function rp_recentlinks_begin_change_title()
{
    ob_start();
}


function rp_recentlinks_end_change_title()
{
    global $rp_new_title;
    $bef = ob_get_clean();
    $pattern = '#(<title[^>]*?'.'>)(.*?)(</title>)#si';
    $rp_new_title = get_option('blogname').' &raquo; '.$rp_new_title;
    echo  preg_replace($pattern, "<title>$rp_new_title</title>", $bef);
}




function rp_recentlinks_inline()
{
    global $posts;

    return rp_recentlinks_inline_merge(count($posts));
}





function rp_recentlinks_inline_css()
{

$css = <<<TEXT

<!-- css block for wp-recent-links -->
<style type="text/css" media="screen">
<!--
.recentlinks-inline {
    list-style:none;
    margin:2em 1em;
    font-size:0.8em;
}

.recentlinks-inline li {
    margin-bottom:1em;
}

-->
</style>

TEXT;

    echo $css;
}










/* undocumented yet, internal use only! */
function rp_recentlinks_inline_merge($entries = 7, $use_days = false, $cat_id = 0)
{
    global $table_prefix, $wpdb, $posts, $tablepost2cat;


    if (  is_category()
            || is_page()
            || is_search()
        ) {
        return;
    }


    // cat_id hack, if using asides
    $cat_id = intval($cat_id);
    if ($cat_id > 0) {
        $sql = " SELECT post_id "
                ." FROM $tablepost2cat "
                ." WHERE category_id='$cat_id' "
                ." ORDER BY post_id ";
        $cat = $wpdb->get_results($sql);

        $cat_arr = array();
        foreach ($cat as $c) {
            $cat_arr[] = $c->post_id;
        }

    }
    // end hack




    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';


    if ($use_days) {
        $__p = array();
        $i = 0;
        $day_counter = 0;
        $__prev_date = '';

        foreach ($posts as $post) {
            if ($i == 0) {
                $__p[] = $post;
                $__prev_date = $post->post_date;
                $day_counter++;
            } else {
                if (date('Y-m-d', strtotime($post->post_date)) == date('Y-m-d', strtotime($__prev_date))) {
                    $__p[] = $post;
                } else {
                    $__p[] = $post;
                    // asides hack
                    if ($cat_id == 0) {
                        $day_counter++;
                    } else {
                        if ($cat_id > 0 && !in_array($post->ID, $cat_arr)) {
                            $day_counter++;
                        }
                    }
                    // end asides hack
                }
                $__prev_date = $post->post_date;
            }
            if ($day_counter == $entries) {
                break;
            }
            $i++;
        }
        $posts = $__p;

    } else {
        if (count($posts) > $entries) {
            $posts = array_slice($posts, 0, $entries);
        }
    }


    $y = '';
    $m = '';
    $d = '';
    if (strlen(get_settings('permalink_structure')) > 0) {
        $y = strval($_GET['year']);
        $m = strval($_GET['monthnum']);
        $d = strval($_GET['day']);

       /*  $y = $_GET['year'];
        $m = $_GET['monthnum'];
        $d = $_GET['day']; */


    } else {
        $y = strval(substr($_GET['m'], 0, 4));
        if (strlen($_GET['m']) > 4) {
            $m = strval(substr($_GET['m'], 4, 2));
        }
        if (strlen($_GET['m']) > 6) {
            $d = strval(substr($_GET['m'], 6, 2));
        }
    }


    if (  strlen($y) == 4 && strlen($m) != 2 && strlen($d) != 2  ) {
        // year
        $now       = $y.'-12-31 23:59:59';
        $last_day  = $y.'-01-01 00:00:00';
    } elseif (  strlen($y) == 4 && strlen($m) == 2 && strlen($d) != 2  ) {
        if ( checkdate($m, '31', $y) ) {
            // month, 31 days
            $now        = $y.'-'.$m.'-31 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '30', $y) ) {
            // month, 30 days
            $now        = $y.'-'.$m.'-30 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '29', $y) ) {
            // month, 29 days
            $now        = $y.'-'.$m.'-29 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } else {
            // month, 28 days
            $now        = $y.'-'.$m.'-28 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        }
    } elseif (  strlen($y) == 4 && strlen($m) == 2 && strlen($d) == 2  ) {
        // date
        $now        = $y.'-'.$m.'-'.$d.' 23:59:59';
        $last_day   = $y.'-'.$m.'-'.$d.' 00:00:00';
    } elseif (  is_paged()  )  {
        // paged
        $now = gmdate('Y-m-d H:i:s', strtotime($posts[0]->post_date));
        $last_day = gmdate('Y-m-d H:i:s', strtotime($posts[count($posts)-1]->post_date));
    } else {
        // index
        $now = gmdate('Y-m-d H:i:s',(time() + (get_settings('gmt_offset') * 3600)));
        $last_day = gmdate('Y-m-d', strtotime($posts[count($posts)-1]->post_date)).' 00:00:00';
    }


    $sql = "SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND date_added > '$last_day' AND link_visible = 'Y' ORDER BY date_added DESC";


    $links = $wpdb->get_results($sql);



    if ($links) {

        for ($i=0; $i < count($links); $i++) {
            $links[$i]->link_text = stripslashes($links[$i]->link_text);
            $links[$i]->link_url = stripslashes($links[$i]->link_url);
            $links[$i]->link_caption = stripslashes($links[$i]->link_caption);
            $links[$i]->link_rel = stripslashes($links[$i]->link_rel);
            $links[$i]->link_target = stripslashes($links[$i]->link_target);

            if (strlen(get_settings('permalink_structure')) > 0) { // using mod_rewrite
                $links[$i]->link_permalink = get_settings('siteurl').'/recent-links/'.date('Y/m', strtotime($links[$i]->date_added)).'/#rlink-'.$links[$i]->ID;
            } else {
                $links[$i]->link_permalink = get_settings('siteurl').'/wp-recent-links.php?y='.date('Y', strtotime($links[$i]->date_added)).'&amp;m='.date('m', strtotime($links[$i]->date_added)).'#rlink-'.$links[$i]->ID;
            }

            if (  is_int(strpos($links[$i]->link_url, '&'))  &&  !strpos($links[$i]->link_url, '&amp;')  &&  !strpos($links[$i]->link_url, '&#038;')  ) {
                $links[$i]->link_url = str_replace('&', '&amp;', $links[$i]->link_url);
            }

            $links[$i]->link_text = strip_tags($links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag, '', $links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag2, '', $links[$i]->link_text);

        }
    }

    $_tmp_arr = array();

    if (count($links) > 0) {
        $posts = array_merge($links, $posts);
    }

    foreach ($posts as $post) {
        $_tmp_item = array();
        if (isset($post->post_date_gmt)) {
            //$_tmp_item['0000_sort'] = $post->post_date_gmt;
            $_tmp_item['0000_sort'] = $post->post_date;
            $_tmp_item['post_object'] = $post;
            $_tmp_item['rp_entry_type'] = 'entry';
        } elseif (isset($post->date_added)) {
            //$_tmp_item['0000_sort'] = date('Y-m-d H:i:s', (strtotime($post->date_added) - (get_settings('gmt_offset') * 3600)));
            $_tmp_item['0000_sort'] = $post->date_added;
            $_tmp_item['post_object'] = $post;
            $_tmp_item['rp_entry_type'] = 'link';
        }
        $_tmp_arr[] = $_tmp_item;
    }
    rsort($_tmp_arr);
    $posts = array();
    $i = 0;
    foreach ($_tmp_arr as $_tmp_item) {
        $posts[$i] = $_tmp_item['post_object'];
        $posts[$i]->rp_entry_type = $_tmp_item['rp_entry_type'];

        $i++;
    }

}














function rp_recentlinks_install() {
   global $table_prefix, $wpdb, $user_level;

   $table_name = $table_prefix . 'recentlinks';

   get_currentuserinfo();
   if ($user_level < 8) { return; }

   if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {

        $now = gmdate('Y-m-d H:i:s', (time() + (get_settings('gmt_offset') * 3600)));
        $sql = "CREATE TABLE $table_name ( "
                             ."ID int(11) NOT NULL AUTO_INCREMENT, "
                             ."link_author int(11) NOT NULL default '0', "
                             ."date_added datetime NOT NULL default '0000-00-00 00:00:00', "
                             ."link_url varchar(255) NOT NULL, "
                             ."link_text varchar(255) NOT NULL, "
                             ."link_caption TEXT NOT NULL, "
                             ."link_rel varchar(255) NOT NULL, "
                             ."link_target varchar(100) NOT NULL, "
                             ."link_visible enum('Y', 'N') NOT NULL default 'Y', "
                             ."PRIMARY KEY (ID) "
                             .")";

          require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
          dbDelta($sql);


          $insert = "INSERT INTO $table_name SET link_author='1', date_added='$now', link_url='http://rebelpixel.com/', link_text='rebelpixel productions', link_caption='WordPress plugins. Weblog design. PHP development. Digital photography.'";
          $results = $wpdb->query( $insert );

          $insert = "INSERT INTO $table_name SET link_author='1', date_added='$now', link_url='http://lyrics.rebelpixel.com/', link_text='lyrics!', link_caption='<strong>lyrics!</strong> is a lyrics weblog for the Filipino people, also from <a href=\"http://rebelpixel.com/\">rebelpixel productions.</a>'";
          $results = $wpdb->query( $insert );

          $insert = "INSERT INTO $table_name SET link_author='1', date_added='$now', link_url='http://rebelpixel.com/projects/wp-recent-links/', link_text='This is wp-recent-links!', link_caption='<strong>wp-recent-links</strong> is a WordPress plugin for adding a links blog to your WordPress&#8211;powered site.'";
          $results = $wpdb->query( $insert );

   }

}





function rp_recentlinks_upgrade_table()
{
    global $table_prefix, $wpdb, $user_level;

    $table_name = $table_prefix . 'recentlinks';

    get_currentuserinfo();
    if ($user_level < 8) { return; }

    if ( get_option('rp_recentlinks_table_version') != '2.0' ) {
        $sql = "ALTER TABLE $table_name MODIFY link_caption TEXT NOT NULL";
        $wpdb->query($sql);
        update_option('rp_recentlinks_table_version', '2.0');
    }
}




function rp_recentlinks_rewrite($rules = '')
{
    if ($rules != '') {
        $added_rules = '### BEGIN wp-recent-links rules'."\n"
                        .'RewriteRule    ^recent-links/feed?/?$  wp-recent-links-rss2.php  [QSA]'."\n"
                        .'RewriteRule    ^recent-links?/?$  wp-recent-links.php  [QSA]'."\n"
                        .'RewriteRule    ^recent-links/([0-9]{4})?/?([0-9]{1,2})?/?$  wp-recent-links.php?y=$1&m=$2  [QSA]'."\n"
                        .'### END wp-recent-links rules'."\n";
        return $added_rules.$rules;
    } else {
        return $rules;
    }
}





if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
   add_action('init', 'rp_recentlinks_install');
   add_action('init', 'rp_recentlinks_upgrade_table');
}








// -------------------------------------------------------------------------
//! Older functions, deprecated. Please try not to use!
// These are aliases for old functions (my-hacks.php days!)
// -------------------------------------------------------------------------

function rpmod_recentlinks($limit = 12, $before = '<li>', $after = '</li>', $between = "\n", $date_append = 'F j')
{
    return rp_recentlinks($limit, false, false, '', false, $date_append, $before, $after, $between);
}

function rpmod_recentlinks_archives_url()
{
    return rp_recentlinks_archives_url();
}

function rpmod_recentlinks_rss2_url()
{
    return rp_recentlinks_rss2_url();
}

function rpmod_recentlinks_month($limit = '', $before = '<li>', $after = '</li>', $between = "\n", $show_link_count = false)
{
    return rp_recentlinks_month($limit, false, false, true, '#', false, 'F j', $before, $after, $between);
}

function rpmod_recentlinks_archives($limit = '', $before = '<li>', $after = '</li>', $between = "\n", $show_link_count = false)
{
    return rp_recentlinks_archives($limit, $show_link_count, $before, $after, $between);
}








/**************----------------  STANDALONE SECTION  ---------------**************/
// Thanks to Kitten's Spaminator I can now write a WP-1.5 plugin! :)


if (function_exists('is_plugin_page') && is_plugin_page()) { ?>
    <div class="wrap">
    <h2>Recent Links</h2>
    <p>A linklog plugin for WordPress, allowing you to have your own blog of
    links without the need for another wp-powered weblog or (gasp!) another
    weblog software. More information at the
    <a href="http://rebelpixel.com/projects/wp-recent-links/">project's page</a>.
    </p>
    </div>
<?php }
else {
    function rp_recentlinks_admin_menu() {
        add_submenu_page('post.php', 'Add Recent Link', 'Add Recent Link', 5, 'recent-links.php'); // adds to the Write menu
        add_management_page('Recent Links', 'Recent Links', 5, 'recent-links.php'); // adds to the Manage menu
    }
}
add_action('admin_menu', 'rp_recentlinks_admin_menu'); // runs the function to add those menus
add_action('wp_head', 'rp_recentlinks_inline_css');
add_filter('mod_rewrite_rules', 'rp_recentlinks_rewrite');

/**************--------------  END STANDALONE SECTION  -------------**************/
?>